<?php

/**
 * Generates a quotable share link inside post content.
 *
 * @access public
 * @param mixed $atts
 * @return void
 */
function nnr_quotables_shortcode($atts) {

	if ( !is_singular() ) {
		return null;
	}

	// Get default shortcode settings

	$shortcode_default = get_option(NNRobots_Quotables::$prefix . 'shortcode_default');

	if ( $shortcode_default === false ) {
		$shortcode_default = array(
			'text'					=> 'Share this Article!',
			'platform'				=> 'twitter',
			'layout'				=> 'box',
			'style'					=> 'color',
			'bitly'					=> '',
			'button_text'			=> 'Share',
			'twitter_username'		=> '',
		);
	}

	$args = shortcode_atts( $shortcode_default, $atts );

	global $post;

	$settings = get_option(NNRobots_Quotables::$prefix . 'settings');

	// Default values

	if ($settings === false) {
		$settings = NNRobots_Quotables::$default;
	}

	// Bitly access token

	$post_link = wp_get_shortlink($post->ID);

	if ( !empty( $settings['bitly'] ) && $settings['bitly'] != '' ) {
		$args['text'] = __( 'Share this article!', NNRobots_Quotables::$text_domain );

		$ch = curl_init();
		curl_setopt ($ch, CURLOPT_URL, 'https://api-ssl.bitly.com/v3/shorten?access_token=' . $settings['bitly'] . '&longUrl=' . urlencode($post_link) . '&format=json');
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
		$result = curl_exec($ch);
		curl_close($ch);

		if (isset(json_decode($result)->data->url)) {
			$post_link = json_decode($result)->data->url;
		}
	}

	if ( !isset($post_link) || empty($post_link) ) {
		$post_link = get_site_url() . '?p=' . $post->ID;
	}

	// Button Text

	if ( empty( $args['button_text'] ) ) {
		$args['button_text'] = __( 'Share', NNRobots_Quotables::$text_domain );
	}

	// Get the featured image

	$featured_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');

	if ( $featured_image ) {
		$featured_image = $featured_image[0];
	}

	$content = '';

	// Display the shortcode

	if ( $args['platform'] != 'pinterest' || ( $args['platform'] == 'pinterest' && $featured_image ) ) {

		$content .= '<p class="' . NNRobots_Quotables::$prefix_dash . 'shortcode ' . NNRobots_Quotables::$prefix_dash . 'container ' . NNRobots_Quotables::$prefix_dash . 'container-' . $args['platform'] . ' ' . NNRobots_Quotables::$prefix_dash . 'style-' . ( $args['layout'] != 'indented' ? $args['style'] : 'dark' ) . ' ' . NNRobots_Quotables::$prefix_dash . 'layout-' . $args['layout'] . '">';

			$link = '';

			// Twitter

			if ( $args['platform'] == 'twitter' ) {

				$twitter_intent = 'https://twitter.com/intent/tweet?text=' . mb_substr( htmlentities($args['text'] . ' ' . $post_link), 0, 138 );

				if ( isset($settings['twitter_username']) && $settings['twitter_username'] != '' ) {
					$twitter_intent .= '&via=' . htmlentities($settings['twitter_username']);
				}

				$link = $twitter_intent;
			}

			// Facebook

			if ( $args['platform'] == 'facebook' ) {

				$link = 'https://www.facebook.com/sharer/sharer.php?u=' . htmlentities($post_link);
			}

			// Google

			if ( $args['platform'] == 'google' ) {

				$link = 'https://plus.google.com/share?url=' . htmlentities($post_link);
			}

			// Pinterest

			if ( $args['platform'] == 'pinterest' ) {

				$link = 'https://www.pinterest.com/pin/create/button/?url=' . htmlentities($post_link) . '&media=' . $featured_image . '&description=' . htmlentities($args['text']);
			}

			// Tumblr

			if ( $args['platform'] == 'tumblr' ) {

				$link = 'https://www.tumblr.com/widgets/share/tool?canonicalUrl=' . htmlentities($post_link);
			}

			// LinkedIn

			if ( $args['platform'] == 'linkedin' ) {

				$link = 'https://www.linkedin.com/shareArticle?url=' . htmlentities($post_link) . '&title=' . htmlentities($post->post_title);
			}

			// Bubble

			if ( $args['layout'] == 'bubble' ) {
				$content .= '<span class="' . NNRobots_Quotables::$prefix_dash . 'icon-wrap">
					<span class="' . NNRobots_Quotables::$prefix_dash . 'icon-container">
						<span class="' . NNRobots_Quotables::$prefix_dash . 'icon-half-circle"></span>
						<span aria-hidden="true" class="' . NNRobots_Quotables::$prefix_dash . 'icon ' . NNRobots_Quotables::$prefix_dash . 'icon-' . $args['platform'] . '"></span>
					</span>
				</span>
				<span class="' . NNRobots_Quotables::$prefix_dash . 'text-container">
					<span class="' . NNRobots_Quotables::$prefix_dash . 'quote-container ' . NNRobots_Quotables::$prefix_dash . 'quote"></span>
					<span class="' . NNRobots_Quotables::$prefix_dash . 'title">' . $args['text'] . '</span>
					<span class="' . NNRobots_Quotables::$prefix_dash . 'share-container">
						<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="' . $link . '" target="_blank">' . $args['button_text'] . '</a>
					</span>
				</span>';
			}

			// Box Layout

			if ( $args['layout'] == 'box' ) {

				$content .= '<span class="' . NNRobots_Quotables::$prefix_dash . 'quote-container ' . NNRobots_Quotables::$prefix_dash . 'quote"></span>';
				$content .= '<span class="' . NNRobots_Quotables::$prefix_dash . 'text-container">
					<span class="' . NNRobots_Quotables::$prefix_dash . 'title">' . $args['text'] . '</span>
				</span>
				<span class="' . NNRobots_Quotables::$prefix_dash . 'share-container">
					<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="' . $link . '" target="_blank">' . $args['button_text'] . '</a>
					<span aria-hidden="true" class="' . NNRobots_Quotables::$prefix_dash . 'icon ' . NNRobots_Quotables::$prefix_dash . 'icon-' . $args['platform'] . '"></span>
				</span>';

			}

			// Indented Layout

			if ( $args['layout'] == 'indented' ) {

				$content .= '<span class="' . NNRobots_Quotables::$prefix_dash . 'share-container">
					<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="' . $link . '" target="_blank"><span aria-hidden="true" class="' . NNRobots_Quotables::$prefix_dash . 'icon ' . NNRobots_Quotables::$prefix_dash . 'icon-' . $args['platform'] . '"></span></a>
				</span>
				<span class="' . NNRobots_Quotables::$prefix_dash . 'text-container">
					<span class="' . NNRobots_Quotables::$prefix_dash . 'title">' . $args['text'] . '</span>
				</span>
				<span class="' . NNRobots_Quotables::$prefix_dash . 'share-text-container">
					<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="' . $link . '" target="_blank">' . $args['button_text'] . '</a>
				</span>';

				/* <script>
					jQuery(document).ready(function($){
						$(".' . NNRobots_Quotables::$prefix_dash . 'shortcode.' . NNRobots_Quotables::$prefix_dash . 'layout-' . $args['layout'] . ' .' . NNRobots_Quotables::$prefix_dash . 'button").css("background-color", $(".entry-content").closest("article").css("background-color"));
					});
				</script> */

			}

		$content .= '</p>';

	}

	wp_enqueue_style( NNRobots_Quotables::$prefix . 'css', NNROBOTS_QUOTABLES_PLUGIN_URL . '/core/css/quotables.css');

	return $content;
}